'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _NavLink = require('./NavLink');

var _NavLink2 = _interopRequireDefault(_NavLink);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Testing NavLink', function () {

  var wrapper = null;

  var link = {
    id: 1,
    name: 'rocket',
    url: '/app/rocket',
    icon: 'rocket',
    color: '#F668CA',
    badge: 1,
    side: 'left'
  };

  var wrapperExpectedProps = function wrapperExpectedProps() {
    return ['id', 'color', 'name', 'url', 'icon', 'badge', 'side', 'onSelect'];
  };

  var onSelect = function onSelect(link) {
    return console.log('selected');
  };

  var getWrapperInstance = function getWrapperInstance(wrapper) {
    return wrapper.renderer._instance._instance;
  };

  var getWrapperProps = function getWrapperProps(wrapper) {
    return wrapper.unrendered.props;
  };

  beforeEach(function () {
    wrapper = (0, _enzyme.shallow)(_react2.default.createElement(_NavLink2.default, _extends({}, link, { onSelect: onSelect })));
  });

  it('should render with props', function () {
    wrapperExpectedProps().forEach(function (prop) {
      return expect(prop in getWrapperProps(wrapper)).toBe(true);
    });
    expect(typeof onSelect === 'undefined' ? 'undefined' : _typeof(onSelect)).toEqual('function');
  });

  it('should toggle hover', function () {
    expect(wrapper.state().hovered).toBe(false);
    getWrapperInstance(wrapper).handleToggleHover();
    expect(wrapper.state().hovered).toBe(true);
  });

  it('should mount indicator for hover', function () {
    var style = getWrapperInstance(wrapper).indicatorStyle('left');
    expect(style.width).toBe(3);
    expect(style.left).toBe(0);
    expect(style.right).toEqual('auto');

    getWrapperInstance(wrapper).handleToggleHover();

    style = getWrapperInstance(wrapper).indicatorStyle('right');
    expect(style.width).toBe(6);
    expect(style.left).toEqual('auto');
    expect(style.right).toBe(0);
  });

  it('should return right color for a route match', function () {
    var color = getWrapperInstance(wrapper).backgroundColor(true);
    expect(color).toEqual('#667D94');

    color = getWrapperInstance(wrapper).backgroundColor(false);
    expect(color).toEqual('transparent');

    getWrapperInstance(wrapper).handleToggleHover();
    color = getWrapperInstance(wrapper).backgroundColor(true);
    expect(color).toEqual('#667D94');

    color = getWrapperInstance(wrapper).backgroundColor(false);
    expect(color).toEqual('#667D94');
  });
});