'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _sinon = require('sinon');

var _sinon2 = _interopRequireDefault(_sinon);

var _enzyme = require('enzyme');

var _reactRouterDom = require('react-router-dom');

var _SideMenu = require('./SideMenu');

var _SideMenu2 = _interopRequireDefault(_SideMenu);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Testing SideMenu', function () {

  var links = [{
    id: 1,
    name: 'rocket',
    url: '/app/rocket',
    icon: 'rocket',
    badge: 3,
    color: '#F668CA'
  }];

  var renderSideMenu = function renderSideMenu(component) {
    return _react2.default.createElement(
      _reactRouterDom.BrowserRouter,
      null,
      component
    );
  };

  var getSideMenuComponent = function getSideMenuComponent(wrapper) {
    return wrapper.props().children;
  };

  var getSideMenuChildren = function getSideMenuChildren(wrapper) {
    return wrapper.children();
  };

  var onSelect = function onSelect(link) {
    return console.log('selected');
  };

  it('should render with props', function () {
    var wrapper = getSideMenuComponent((0, _enzyme.mount)(renderSideMenu(_react2.default.createElement(_SideMenu2.default, { links: links, onSelectLink: onSelect }))));

    expect(wrapper.props.links[0]).toEqual(links[0]);
    expect(_typeof(wrapper.props.onSelectLink)).toBe('function');
  });

  it('should render NavLink with props', function () {
    var wrapper = getSideMenuChildren((0, _enzyme.mount)(renderSideMenu(_react2.default.createElement(_SideMenu2.default, { links: links, onSelectLink: onSelect }))));

    expect('side' in wrapper.props()).toBe(true);
    expect('id' in wrapper.props()).toBe(true);
    expect('name' in wrapper.props()).toBe(true);
    expect('badge' in wrapper.props()).toBe(true);
    expect('url' in wrapper.props()).toBe(true);
    expect('icon' in wrapper.props()).toBe(true);
    expect('color' in wrapper.props()).toBe(true);
    expect('onSelect' in wrapper.props()).toBe(true);

    expect(_typeof(wrapper.props().onSelect)).toEqual('function');
  });

  it('should render NavLink on the right', function () {
    var wrapper = getSideMenuChildren((0, _enzyme.mount)(renderSideMenu(_react2.default.createElement(_SideMenu2.default, { links: links, position: 'right', onSelectLink: onSelect }))));

    expect('side' in wrapper.props()).toBe(true);
    expect(wrapper.props().side).toEqual('right');
  });

  it('should select link', function () {
    var onSelectLink = _sinon2.default.spy();

    var wrapper = getSideMenuChildren((0, _enzyme.mount)(renderSideMenu(_react2.default.createElement(_SideMenu2.default, { links: links, onSelectLink: onSelectLink }))));
    wrapper.simulate('click');
    expect(onSelectLink.calledOnce).toBe(true);
  });
});