import React, {Component} from 'react';
import PropTypes from 'prop-types';

import FontAwesome from 'react-fontawesome';
import {Route} from 'react-router-dom';

const style = {
  container: {
    position: 'relative',
    width: '100%',
    height: 58,
    textAlign: 'center',
    borderBottom: '1px solid #667D94',
    color: 'white',
    cursor: 'pointer'
  },
  badge: {
    position: 'absolute',
    right: 24,
    padding: '2px 8px',
    zIndex: 100,
    top: 4,
    backgroundColor: '#E91E63',
    borderRadius: '40%',
    fontSize: '.75rem',
    fontWeight: 600
  },
  name: {
    textTransform: 'uppercase',
    fontSize: '0.65rem'
  },
  icon: {
    height: 24,
    paddingTop: 12
  }
};

class NavLink extends Component {
  constructor(props) {
    super(props);
    this.state = {hovered: false};
  }

  indicatorStyle = (match, side) => ({
    height: 58,
    width: match || this.state.hovered ? 4 : 0,
    position: 'absolute',
    backgroundColor: 'rgb(79, 195, 247)',
    left: side === 'left' ? 0 : 'auto',
    right: side === 'right' ? 0 : 'auto'
  });

  backgroundColor = match =>
    match || this.state.hovered ? '#667D94' : 'transparent';

  handleLinkSelect = () => {
    const {id, name, url, onSelect} = this.props;
    onSelect({id, name, url});
  };

  handleHover = () => this.setState({hovered: true});

  handleBlur = () => this.setState({hovered: false});

  render() {
    const {side, badge, url, name, icon, color} = this.props;

    return (
      <Route path={url} strict children={({ match }) => (
        <div
          className="nav-link__container"
          style={{
            ...style.container,
            backgroundColor: this.backgroundColor(match)
          }}
          onMouseEnter={this.handleHover}
          onMouseLeave={this.handleBlur}
          onClick={this.handleLinkSelect}
        >
          <div
            className="nav-link__indicator"
            style={this.indicatorStyle(match, side)}
          >
          </div>
          {!!badge &&
            <div
              className="nav-link__badge"
              style={style.badge}>
                {badge}
            </div>
          }
          <FontAwesome
            name={icon}
            className="nav-link__icon"
            style={{...style.icon, color: match ? 'rgb(79, 195, 247)' : 'white'}}
          />
          <div
            className="nav-link__name"
            style={style.name}>
              {name}
          </div>
        </div>
      )}/>
    );
  }
}

NavLink.propTypes = {
  id: PropTypes.number.isRequired,
  name: PropTypes.string.isRequired,
  url: PropTypes.string.isRequired,
  icon: PropTypes.string.isRequired,
  badge: PropTypes.number,
  side: PropTypes.string,
  onSelect: PropTypes.func.isRequired
};

export default NavLink;
