import React from 'react';
import {shallow} from 'enzyme';

import NavLink from './NavLink';

describe('Testing NavLink', () => {

  let wrapper = null;

  const link = {
    id: 1,
    name: 'rocket',
    url: '/app/rocket',
    icon: 'rocket',
    color: '#F668CA',
    badge: 1,
    side: 'left'
  };

  const wrapperExpectedProps = () => [
    'id', 'color', 'name', 'url', 'icon', 'badge', 'side', 'onSelect'
  ];

  const onSelect = link => console.log('selected');

  const getWrapperInstance = wrapper =>
    wrapper.renderer._instance._instance;

  const getWrapperProps = wrapper =>
    wrapper.unrendered.props;

  beforeEach(() => {
    wrapper = shallow(
      <NavLink {...link} onSelect={onSelect} />
    );
  });

  it('should render with props', function() {
    wrapperExpectedProps().forEach(prop =>
      expect(prop in getWrapperProps(wrapper)).toBe(true)
    );
    expect(typeof(onSelect)).toEqual('function');
  });

  it('should toggle hover', function() {
    expect(wrapper.state().hovered).toBe(false);
    getWrapperInstance(wrapper).handleToggleHover();
    expect(wrapper.state().hovered).toBe(true);
  });

  it('should mount indicator for hover', function() {
    let style = getWrapperInstance(wrapper).indicatorStyle('left');
    expect(style.width).toBe(3);
    expect(style.left).toBe(0);
    expect(style.right).toEqual('auto');

    getWrapperInstance(wrapper).handleToggleHover();

    style = getWrapperInstance(wrapper).indicatorStyle('right');
    expect(style.width).toBe(6);
    expect(style.left).toEqual('auto');
    expect(style.right).toBe(0);
  });

  it('should return right color for a route match', () => {
    let color = getWrapperInstance(wrapper).backgroundColor(true);
    expect(color).toEqual('#667D94');

    color = getWrapperInstance(wrapper).backgroundColor(false);
    expect(color).toEqual('transparent');

    getWrapperInstance(wrapper).handleToggleHover();
    color = getWrapperInstance(wrapper).backgroundColor(true);
    expect(color).toEqual('#667D94');

    color = getWrapperInstance(wrapper).backgroundColor(false);
    expect(color).toEqual('#667D94');
  });
});
