import React, {Component} from 'react';
import PropTypes from 'prop-types';

import NavLink from '../navLink/NavLink';

const style = {
  menu: {
    fontFamily: 'Roboto, sans-serif',
    width: 108,
    color: 'white',
    backgroundColor: '#36526D',
    zIndex: 99,
    position: 'absolute',
    top: 0,
    bottom: 0,
    overflowY: 'auto',
    overflowX: 'hidden',
    boxShadow: '0 3px 6px rgba(0,0,0,0.16), 0 3px 6px rgba(0,0,0,0.23)'
  }
};

class SideMenu extends Component {

  render() {
    const {links, position, onSelectLink} = this.props;
    const side = position || 'left';

    const componentPosition = {
      left: side === 'left' ? 0 : 'auto',
      right: side === 'right' ? 0 : 'auto'
    };

    return (
      <div
        className="side-menu__container"
        style={{...style.menu, ...componentPosition}}>
          {links.map(link =>
            <NavLink
              key={link.id}
              side={side}
              {...link}
              onSelect={onSelectLink}
            />
          )}
      </div>
    );
  }
}

SideMenu.propTypes = {
  links: PropTypes.arrayOf(PropTypes.shape({
    id: PropTypes.number.isRequired,
    name: PropTypes.string.isRequired,
    url: PropTypes.string.isRequired,
    icon: PropTypes.string.isRequired,
    badge: PropTypes.number
  })).isRequired,
  position: PropTypes.string,
  onSelectLink: PropTypes.func.isRequired
};

export default SideMenu;
