import React from 'react';
import sinon from 'sinon';
import {mount} from 'enzyme';
import {BrowserRouter as Router} from 'react-router-dom';

import SideMenu from './SideMenu';

describe('Testing SideMenu', () => {

  const links = [{
    id: 1,
    name: 'rocket',
    url: '/app/rocket',
    icon: 'rocket',
    badge: 3,
    color: '#F668CA'
  }];

  const renderSideMenu = component => (<Router>{component}</Router>);

  const getSideMenuComponent = wrapper => wrapper.props().children;

  const getSideMenuChildren = wrapper => wrapper.children();

  const onSelect = link => console.log('selected');

  it('should render with props', () => {
    const wrapper = getSideMenuComponent(
      mount(renderSideMenu(
        <SideMenu links={links} onSelectLink={onSelect} />
      ))
    );

    expect(wrapper.props.links[0]).toEqual(links[0]);
    expect(typeof(wrapper.props.onSelectLink)).toBe('function');
  });

  it('should render NavLink with props', () => {
    const wrapper = getSideMenuChildren(
      mount(renderSideMenu(
        <SideMenu links={links} onSelectLink={onSelect} />
      ))
    );

    expect('side' in wrapper.props()).toBe(true);
    expect('id' in wrapper.props()).toBe(true);
    expect('name' in wrapper.props()).toBe(true);
    expect('badge' in wrapper.props()).toBe(true);
    expect('url' in wrapper.props()).toBe(true);
    expect('icon' in wrapper.props()).toBe(true);
    expect('color' in wrapper.props()).toBe(true);
    expect('onSelect' in wrapper.props()).toBe(true);

    expect(typeof(wrapper.props().onSelect)).toEqual('function');
  });

  it('should render NavLink on the right', () => {
    const wrapper = getSideMenuChildren(
      mount(renderSideMenu(
        <SideMenu links={links} position="right" onSelectLink={onSelect} />
      ))
    );

    expect('side' in wrapper.props()).toBe(true);
    expect(wrapper.props().side).toEqual('right');
  });

  it('should select link', () => {
    const onSelectLink = sinon.spy();

    const wrapper = getSideMenuChildren(
      mount(renderSideMenu(
        <SideMenu links={links} onSelectLink={onSelectLink} />
      ))
    );
    wrapper.simulate('click');
    expect(onSelectLink.calledOnce).toBe(true);
  });
});
